(window.webpackJsonp=window.webpackJsonp||[]).push([[370],{565:function(t){t.exports=JSON.parse('{"data":{"sah":{"nu":["latn"],"year":{"0":"быйыл","1":"эһиил","future":{"other":"{0} сылынан"},"past":{"other":"{0} сыл ынараа өттүгэр"},"-1":"Былырыын"},"year-short":{"0":"быйыл","1":"эһиил","future":{"other":"{0} сылынан"},"past":{"other":"{0} сыл ынараа өттүгэр"},"-1":"Былырыын"},"year-narrow":{"0":"быйыл","1":"эһиил","future":{"other":"{0} сылынан"},"past":{"other":"{0} сыл ынараа өттүгэр"},"-1":"Былырыын"},"quarter":{"0":"бу кыбаартал","1":"кэлэр кыбаартал","future":{"other":"{0} кыбаарталынан"},"past":{"other":"{0} кыбаартал анараа өттүгэр"},"-1":"ааспыт кыбаартал"},"quarter-short":{"0":"бу кыбаартал","1":"кэлэр кыбаартал","future":{"other":"{0} кыбаарталынан"},"past":{"other":"{0} кыб. анараа өттүгэр"},"-1":"ааспыт кыбаартал"},"quarter-narrow":{"0":"бу кыбаартал","1":"кэлэр кыбаартал","future":{"other":"{0} кыбаарталынан"},"past":{"other":"{0} кыб. анараа өттүгэр"},"-1":"ааспыт кыбаартал"},"month":{"0":"бу ый","1":"аныгыскы ый","future":{"other":"{0} ыйынан"},"past":{"other":"{0} ый ынараа өттүгэр"},"-1":"ааспыт ый"},"month-short":{"0":"бу ый","1":"аныгыскы ый","future":{"other":"{0} ыйынан"},"past":{"other":"{0} ый ынараа өттүгэр"},"-1":"ааспыт ый"},"month-narrow":{"0":"бу ый","1":"аныгыскы ый","future":{"other":"{0} ыйынан"},"past":{"other":"{0} ый ынараа өттүгэр"},"-1":"ааспыт ый"},"week":{"0":"бу нэдиэлэ","1":"кэлэр нэдиэлэ","future":{"other":"{0} нэдиэлэннэн"},"past":{"other":"{0} нэдиэлэ анараа өттүгэр"},"-1":"ааспыт нэдиэлэ"},"week-short":{"0":"бу нэдиэлэ","1":"кэлэр нэдиэлэ","future":{"other":"{0} нэдиэлэннэн"},"past":{"other":"{0} нэдиэлэ анараа өттүгэр"},"-1":"ааспыт нэдиэлэ"},"week-narrow":{"0":"бу нэдиэлэ","1":"кэлэр нэдиэлэ","future":{"other":"{0} нэдиэлэннэн"},"past":{"other":"{0} нэдиэлэ анараа өттүгэр"},"-1":"ааспыт нэдиэлэ"},"day":{"0":"Бүгүн","1":"Сарсын","2":"Өйүүн","future":{"other":"{0} күнүнэн"},"past":{"other":"{0} күн ынараа өттүгэр"},"-2":"Иллэрээ күн","-1":"Бэҕэһээ"},"day-short":{"0":"Бүгүн","1":"Сарсын","2":"Өйүүн","future":{"other":"{0} күнүнэн"},"past":{"other":"{0} күн ынараа өттүгэр"},"-2":"Иллэрээ күн","-1":"Бэҕэһээ"},"day-narrow":{"0":"Бүгүн","1":"Сарсын","2":"Өйүүн","future":{"other":"{0} күнүнэн"},"past":{"other":"{0} күн ынараа өттүгэр"},"-2":"Иллэрээ күн","-1":"Бэҕэһээ"},"hour":{"0":"this hour","future":{"other":"{0} чааһынан"},"past":{"other":"{0} чаас ынараа өттүгэр"}},"hour-short":{"0":"this hour","future":{"other":"{0} чааһынан"},"past":{"other":"{0} чаас ынараа өттүгэр"}},"hour-narrow":{"0":"this hour","future":{"other":"{0} чааһынан"},"past":{"other":"{0} чаас ынараа өттүгэр"}},"minute":{"0":"this minute","future":{"other":"{0} мүнүүтэннэн"},"past":{"other":"{0} мүнүүтэ ынараа өттүгэр"}},"minute-short":{"0":"this minute","future":{"other":"{0} мүнүүтэннэн"},"past":{"other":"{0} мүнүүтэ ынараа өттүгэр"}},"minute-narrow":{"0":"this minute","future":{"other":"{0} мүнүүтэннэн"},"past":{"other":"{0} мүнүүтэ ынараа өттүгэр"}},"second":{"0":"билигин","future":{"other":"{0} сөкүүндэннэн"},"past":{"other":"{0} сөкүүндэ ынараа өттүгэр"}},"second-short":{"0":"билигин","future":{"other":"{0} сөкүүндэннэн"},"past":{"other":"{0} сөк. анараа өттүгэр"}},"second-narrow":{"0":"билигин","future":{"other":"{0} сөкүүндэннэн"},"past":{"other":"{0} сөк. анараа өттүгэр"}}}},"availableLocales":["sah"],"aliases":{},"parentLocales":{}}')}}]);
//# sourceMappingURL=370.8b288954fc14d7f82d4f.index.js.map