(window.webpackJsonp=window.webpackJsonp||[]).push([[252],{447:function(e){e.exports=JSON.parse('{"data":{"el":{"nu":["latn"],"year":{"0":"φέτος","1":"επόμενο έτος","future":{"one":"σε {0} έτος","other":"σε {0} έτη"},"past":{"one":"πριν από {0} έτος","other":"πριν από {0} έτη"},"-1":"πέρσι"},"year-short":{"0":"φέτος","1":"επόμενο έτος","future":{"one":"σε {0} έτος","other":"σε {0} έτη"},"past":{"one":"πριν από {0} έτος","other":"πριν από {0} έτη"},"-1":"πέρσι"},"year-narrow":{"0":"φέτος","1":"επόμενο έτος","future":{"one":"σε {0} έτος","other":"σε {0} έτη"},"past":{"one":"{0} έτος πριν","other":"{0} έτη πριν"},"-1":"πέρσι"},"quarter":{"0":"τρέχον τρίμηνο","1":"επόμενο τρίμηνο","future":{"one":"σε {0} τρίμηνο","other":"σε {0} τρίμηνα"},"past":{"one":"πριν από {0} τρίμηνο","other":"πριν από {0} τρίμηνα"},"-1":"προηγούμενο τρίμηνο"},"quarter-short":{"0":"τρέχον τρίμ.","1":"επόμ. τρίμ.","future":{"one":"σε {0} τρίμ.","other":"σε {0} τρίμ."},"past":{"one":"πριν από {0} τρίμ.","other":"πριν από {0} τρίμ."},"-1":"προηγ. τρίμ."},"quarter-narrow":{"0":"τρέχον τρίμ.","1":"επόμ. τρίμ.","future":{"one":"σε {0} τρίμ.","other":"σε {0} τρίμ."},"past":{"one":"{0} τρίμ. πριν","other":"{0} τρίμ. πριν"},"-1":"προηγ. τρίμ."},"month":{"0":"τρέχων μήνας","1":"επόμενος μήνας","future":{"one":"σε {0} μήνα","other":"σε {0} μήνες"},"past":{"one":"πριν από {0} μήνα","other":"πριν από {0} μήνες"},"-1":"προηγούμενος μήνας"},"month-short":{"0":"τρέχων μήνας","1":"επόμενος μήνας","future":{"one":"σε {0} μήνα","other":"σε {0} μήνες"},"past":{"one":"πριν από {0} μήνα","other":"πριν από {0} μήνες"},"-1":"προηγούμενος μήνας"},"month-narrow":{"0":"τρέχων μήνας","1":"επόμενος μήνας","future":{"one":"σε {0} μ.","other":"σε {0} μ."},"past":{"one":"{0} μ. πριν","other":"{0} μ. πριν"},"-1":"προηγούμενος μήνας"},"week":{"0":"τρέχουσα εβδομάδα","1":"επόμενη εβδομάδα","future":{"one":"σε {0} εβδομάδα","other":"σε {0} εβδομάδες"},"past":{"one":"πριν από {0} εβδομάδα","other":"πριν από {0} εβδομάδες"},"-1":"προηγούμενη εβδομάδα"},"week-short":{"0":"τρέχουσα εβδομάδα","1":"επόμενη εβδομάδα","future":{"one":"σε {0} εβδ.","other":"σε {0} εβδ."},"past":{"one":"πριν από {0} εβδ.","other":"πριν από {0} εβδ."},"-1":"προηγούμενη εβδομάδα"},"week-narrow":{"0":"τρέχουσα εβδομάδα","1":"επόμενη εβδομάδα","future":{"one":"σε {0} εβδ.","other":"σε {0} εβδ."},"past":{"one":"{0} εβδ. πριν","other":"{0} εβδ. πριν"},"-1":"προηγούμενη εβδομάδα"},"day":{"0":"σήμερα","1":"αύριο","2":"μεθαύριο","future":{"one":"σε {0} ημέρα","other":"σε {0} ημέρες"},"past":{"one":"πριν από {0} ημέρα","other":"πριν από {0} ημέρες"},"-2":"προχθές","-1":"χθες"},"day-short":{"0":"σήμερα","1":"αύριο","2":"μεθαύριο","future":{"one":"σε {0} ημ.","other":"σε {0} ημ."},"past":{"one":"πριν από {0} ημ.","other":"πριν από {0} ημ."},"-2":"προχθές","-1":"χθες"},"day-narrow":{"0":"σήμερα","1":"αύριο","2":"μεθαύριο","future":{"one":"σε {0} ημ.","other":"σε {0} ημ."},"past":{"one":"{0} ημ. πριν","other":"{0} ημ. πριν"},"-2":"προχθές","-1":"χθες"},"hour":{"0":"τρέχουσα ώρα","future":{"one":"σε {0} ώρα","other":"σε {0} ώρες"},"past":{"one":"πριν από {0} ώρα","other":"πριν από {0} ώρες"}},"hour-short":{"0":"τρέχουσα ώρα","future":{"one":"σε {0} ώ.","other":"σε {0} ώ."},"past":{"one":"πριν από {0} ώ.","other":"πριν από {0} ώ."}},"hour-narrow":{"0":"τρέχουσα ώρα","future":{"one":"σε {0} ώ.","other":"σε {0} ώ."},"past":{"one":"{0} ώ. πριν","other":"{0} ώ. πριν"}},"minute":{"0":"τρέχον λεπτό","future":{"one":"σε {0} λεπτό","other":"σε {0} λεπτά"},"past":{"one":"πριν από {0} λεπτό","other":"πριν από {0} λεπτά"}},"minute-short":{"0":"τρέχον λεπτό","future":{"one":"σε {0} λεπ.","other":"σε {0} λεπ."},"past":{"one":"πριν από {0} λεπ.","other":"πριν από {0} λεπ."}},"minute-narrow":{"0":"τρέχον λεπτό","future":{"one":"σε {0} λ.","other":"σε {0} λ."},"past":{"one":"{0} λ. πριν","other":"{0} λ. πριν"}},"second":{"0":"τώρα","future":{"one":"σε {0} δευτερόλεπτο","other":"σε {0} δευτερόλεπτα"},"past":{"one":"πριν από {0} δευτερόλεπτο","other":"πριν από {0} δευτερόλεπτα"}},"second-short":{"0":"τώρα","future":{"one":"σε {0} δευτ.","other":"σε {0} δευτ."},"past":{"one":"πριν από {0} δευτ.","other":"πριν από {0} δευτ."}},"second-narrow":{"0":"τώρα","future":{"one":"σε {0} δ.","other":"σε {0} δ."},"past":{"one":"{0} δ. πριν","other":"{0} δ. πριν"}}}},"availableLocales":["el-CY","el"],"aliases":{},"parentLocales":{}}')}}]);
//# sourceMappingURL=252.8b288954fc14d7f82d4f.index.js.map