(window.webpackJsonp=window.webpackJsonp||[]).push([[299],{494:function(e){e.exports=JSON.parse('{"data":{"kk":{"nu":["latn"],"year":{"0":"биылғы жыл","1":"келесі жыл","future":{"one":"{0} жылдан кейін","other":"{0} жылдан кейін"},"past":{"one":"{0} жыл бұрын","other":"{0} жыл бұрын"},"-1":"былтырғы жыл"},"year-short":{"0":"биылғы жыл","1":"келесі жыл","future":{"one":"{0} ж. кейін","other":"{0} ж. кейін"},"past":{"one":"{0} ж. бұрын","other":"{0} ж. бұрын"},"-1":"былтырғы жыл"},"year-narrow":{"0":"биылғы жыл","1":"келесі жыл","future":{"one":"{0} ж. кейін","other":"{0} ж. кейін"},"past":{"one":"{0} ж. бұрын","other":"{0} ж. бұрын"},"-1":"былтырғы жыл"},"quarter":{"0":"осы тоқсан","1":"келесі тоқсан","future":{"one":"{0} тоқсаннан кейін","other":"{0} тоқсаннан кейін"},"past":{"one":"{0} тоқсан бұрын","other":"{0} тоқсан бұрын"},"-1":"өткен тоқсан"},"quarter-short":{"0":"осы тоқсан","1":"келесі тоқсан","future":{"one":"{0} тқс. кейін","other":"{0} тқс. кейін"},"past":{"one":"{0} тқс. бұрын","other":"{0} тқс. бұрын"},"-1":"өткен тоқсан"},"quarter-narrow":{"0":"осы тоқсан","1":"келесі тоқсан","future":{"one":"{0} тқс. кейін","other":"{0} тқс. кейін"},"past":{"one":"{0} тқс. бұрын","other":"{0} тқс. бұрын"},"-1":"өткен тоқсан"},"month":{"0":"осы ай","1":"келесі ай","future":{"one":"{0} айдан кейін","other":"{0} айдан кейін"},"past":{"one":"{0} ай бұрын","other":"{0} ай бұрын"},"-1":"өткен ай"},"month-short":{"0":"осы ай","1":"келесі ай","future":{"one":"{0} айдан кейін","other":"{0} айдан кейін"},"past":{"one":"{0} ай бұрын","other":"{0} ай бұрын"},"-1":"өткен ай"},"month-narrow":{"0":"осы ай","1":"келесі ай","future":{"one":"{0} айдан кейін","other":"{0} айдан кейін"},"past":{"one":"{0} ай бұрын","other":"{0} ай бұрын"},"-1":"өткен ай"},"week":{"0":"осы апта","1":"келесі апта","future":{"one":"{0} аптадан кейін","other":"{0} аптадан кейін"},"past":{"one":"{0} апта бұрын","other":"{0} апта бұрын"},"-1":"өткен апта"},"week-short":{"0":"осы апта","1":"келесі апта","future":{"one":"{0} ап. кейін","other":"{0} ап. кейін"},"past":{"one":"{0} ап. бұрын","other":"{0} ап. бұрын"},"-1":"өткен апта"},"week-narrow":{"0":"осы апта","1":"келесі апта","future":{"one":"{0} ап. кейін","other":"{0} ап. кейін"},"past":{"one":"{0} ап. бұрын","other":"{0} ап. бұрын"},"-1":"өткен апта"},"day":{"0":"бүгін","1":"ертең","2":"бүрсігүні","future":{"one":"{0} күннен кейін","other":"{0} күннен кейін"},"past":{"one":"{0} күн бұрын","other":"{0} күн бұрын"},"-2":"алдыңгүні","-1":"кеше"},"day-short":{"0":"бүгін","1":"ертең","2":"бүрсігүні","future":{"one":"{0} күннен кейін","other":"{0} күннен кейін"},"past":{"one":"{0} күн бұрын","other":"{0} күн бұрын"},"-2":"алдыңғы күні","-1":"кеше"},"day-narrow":{"0":"бүгін","1":"ертең","2":"бүрсігүні","future":{"one":"{0} күннен кейін","other":"{0} күннен кейін"},"past":{"one":"{0} күн бұрын","other":"{0} күн бұрын"},"-2":"алдыңғы күні","-1":"кеше"},"hour":{"0":"осы сағат","future":{"one":"{0} сағаттан кейін","other":"{0} сағаттан кейін"},"past":{"one":"{0} сағат бұрын","other":"{0} сағат бұрын"}},"hour-short":{"0":"осы сағат","future":{"one":"{0} сағ. кейін","other":"{0} сағ. кейін"},"past":{"one":"{0} сағ. бұрын","other":"{0} сағ. бұрын"}},"hour-narrow":{"0":"осы сағат","future":{"one":"{0} сағ. кейін","other":"{0} сағ. кейін"},"past":{"one":"{0} сағ. бұрын","other":"{0} сағ. бұрын"}},"minute":{"0":"осы минут","future":{"one":"{0} минуттан кейін","other":"{0} минуттан кейін"},"past":{"one":"{0} минут бұрын","other":"{0} минут бұрын"}},"minute-short":{"0":"осы минут","future":{"one":"{0} мин. кейін","other":"{0} мин. кейін"},"past":{"one":"{0} мин. бұрын","other":"{0} мин. бұрын"}},"minute-narrow":{"0":"осы минут","future":{"one":"{0} мин. кейін","other":"{0} мин. кейін"},"past":{"one":"{0} мин. бұрын","other":"{0} мин. бұрын"}},"second":{"0":"қазір","future":{"one":"{0} секундтан кейін","other":"{0} секундтан кейін"},"past":{"one":"{0} секунд бұрын","other":"{0} секунд бұрын"}},"second-short":{"0":"қазір","future":{"one":"{0} сек. кейін","other":"{0} сек. кейін"},"past":{"one":"{0} сек. бұрын","other":"{0} сек. бұрын"}},"second-narrow":{"0":"қазір","future":{"one":"{0} сек. кейін","other":"{0} сек. кейін"},"past":{"one":"{0} сек. бұрын","other":"{0} сек. бұрын"}}}},"availableLocales":["kk"],"aliases":{"kk-Cyrl-KZ":"kk-KZ"},"parentLocales":{}}')}}]);
//# sourceMappingURL=299.8b288954fc14d7f82d4f.index.js.map