(window.webpackJsonp=window.webpackJsonp||[]).push([[265],{460:function(e){e.exports=JSON.parse('{"data":{"fur":{"nu":["latn"],"year":{"0":"this year","1":"next year","future":{"one":"ca di {0} an","other":"ca di {0} agns"},"past":{"one":"{0} an indaûr","other":"{0} agns indaûr"},"-1":"last year"},"year-short":{"0":"this year","1":"next year","future":{"one":"ca di {0} an","other":"ca di {0} agns"},"past":{"one":"{0} an indaûr","other":"{0} agns indaûr"},"-1":"last year"},"year-narrow":{"0":"this year","1":"next year","future":{"one":"ca di {0} an","other":"ca di {0} agns"},"past":{"one":"{0} an indaûr","other":"{0} agns indaûr"},"-1":"last year"},"quarter":{"0":"this quarter","1":"next quarter","future":{"other":"+{0} Q"},"past":{"other":"-{0} Q"},"-1":"last quarter"},"quarter-short":{"0":"this quarter","1":"next quarter","future":{"other":"+{0} Q"},"past":{"other":"-{0} Q"},"-1":"last quarter"},"quarter-narrow":{"0":"this quarter","1":"next quarter","future":{"other":"+{0} Q"},"past":{"other":"-{0} Q"},"-1":"last quarter"},"month":{"0":"this month","1":"next month","future":{"one":"ca di {0} mês","other":"ca di {0} mês"},"past":{"one":"{0} mês indaûr","other":"{0} mês indaûr"},"-1":"last month"},"month-short":{"0":"this month","1":"next month","future":{"one":"ca di {0} mês","other":"ca di {0} mês"},"past":{"one":"{0} mês indaûr","other":"{0} mês indaûr"},"-1":"last month"},"month-narrow":{"0":"this month","1":"next month","future":{"one":"ca di {0} mês","other":"ca di {0} mês"},"past":{"one":"{0} mês indaûr","other":"{0} mês indaûr"},"-1":"last month"},"week":{"0":"this week","1":"next week","future":{"one":"ca di {0} setemane","other":"ca di {0} setemanis"},"past":{"one":"{0} setemane indaûr","other":"{0} setemanis indaûr"},"-1":"last week"},"week-short":{"0":"this week","1":"next week","future":{"one":"ca di {0} setemane","other":"ca di {0} setemanis"},"past":{"one":"{0} setemane indaûr","other":"{0} setemanis indaûr"},"-1":"last week"},"week-narrow":{"0":"this week","1":"next week","future":{"one":"ca di {0} setemane","other":"ca di {0} setemanis"},"past":{"one":"{0} setemane indaûr","other":"{0} setemanis indaûr"},"-1":"last week"},"day":{"0":"vuê","1":"doman","2":"passantdoman","future":{"one":"ca di {0} zornade","other":"ca di {0} zornadis"},"past":{"one":"{0} zornade indaûr","other":"{0} zornadis indaûr"},"-2":"îr l’altri","-1":"îr"},"day-short":{"0":"vuê","1":"doman","2":"passantdoman","future":{"one":"ca di {0} zornade","other":"ca di {0} zornadis"},"past":{"one":"{0} zornade indaûr","other":"{0} zornadis indaûr"},"-2":"îr l’altri","-1":"îr"},"day-narrow":{"0":"vuê","1":"doman","2":"passantdoman","future":{"one":"ca di {0} zornade","other":"ca di {0} zornadis"},"past":{"one":"{0} zornade indaûr","other":"{0} zornadis indaûr"},"-2":"îr l’altri","-1":"îr"},"hour":{"0":"this hour","future":{"one":"ca di {0} ore","other":"ca di {0} oris"},"past":{"one":"{0} ore indaûr","other":"{0} oris indaûr"}},"hour-short":{"0":"this hour","future":{"one":"ca di {0} ore","other":"ca di {0} oris"},"past":{"one":"{0} ore indaûr","other":"{0} oris indaûr"}},"hour-narrow":{"0":"this hour","future":{"one":"ca di {0} ore","other":"ca di {0} oris"},"past":{"one":"{0} ore indaûr","other":"{0} oris indaûr"}},"minute":{"0":"this minute","future":{"one":"ca di {0} minût","other":"ca di {0} minûts"},"past":{"one":"{0} minût indaûr","other":"{0} minûts indaûr"}},"minute-short":{"0":"this minute","future":{"one":"ca di {0} minût","other":"ca di {0} minûts"},"past":{"one":"{0} minût indaûr","other":"{0} minûts indaûr"}},"minute-narrow":{"0":"this minute","future":{"one":"ca di {0} minût","other":"ca di {0} minûts"},"past":{"one":"{0} minût indaûr","other":"{0} minûts indaûr"}},"second":{"0":"now","future":{"one":"ca di {0} secont","other":"ca di {0} seconts"},"past":{"one":"{0} secont indaûr","other":"{0} seconts indaûr"}},"second-short":{"0":"now","future":{"one":"ca di {0} secont","other":"ca di {0} seconts"},"past":{"one":"{0} secont indaûr","other":"{0} seconts indaûr"}},"second-narrow":{"0":"now","future":{"one":"ca di {0} secont","other":"ca di {0} seconts"},"past":{"one":"{0} secont indaûr","other":"{0} seconts indaûr"}}}},"availableLocales":["fur"],"aliases":{},"parentLocales":{}}')}}]);
//# sourceMappingURL=265.8b288954fc14d7f82d4f.index.js.map