(window.webpackJsonp=window.webpackJsonp||[]).push([[359],{554:function(t){t.exports=JSON.parse('{"data":{"ps-PK":{"year":{"0":"سږکال","1":"بل کال","future":{"one":"په {0} کال کے","other":"په {0} کالونو کے"},"past":{"one":"{0} کال مخکے","other":"{0} کاله مخکے"},"-1":"پروسږکال"},"year-short":{"0":"سږکال","1":"بل کال","future":{"one":"په {0} کال کے","other":"په {0} کالونو کے"},"past":{"one":"{0} کال مخکے","other":"{0} کاله مخکے"},"-1":"پروسږکال"},"year-narrow":{"0":"سږکال","1":"بل کال","future":{"one":"په {0} کال کے","other":"په {0} کالونو کے"},"past":{"one":"{0} کال مخکے","other":"{0} کاله مخکے"},"-1":"پروسږکال"}},"ps":{"nu":["arabext"],"year":{"0":"سږکال","1":"بل کال","future":{"one":"په {0} کال کې","other":"په {0} کالونو کې"},"past":{"one":"{0} کال مخکې","other":"{0} کاله مخکې"},"-1":"پروسږکال"},"year-short":{"0":"سږکال","1":"بل کال","future":{"one":"په {0} کال کې","other":"په {0} کالونو کې"},"past":{"one":"{0} کال مخکې","other":"{0} کاله مخکې"},"-1":"پروسږکال"},"year-narrow":{"0":"سږکال","1":"بل کال","future":{"one":"په {0} کال کې","other":"په {0} کالونو کې"},"past":{"one":"{0} کال مخکې","other":"{0} کاله مخکې"},"-1":"پروسږکال"},"quarter":{"0":"this quarter","1":"next quarter","future":{"other":"+{0} Q"},"past":{"other":"-{0} Q"},"-1":"last quarter"},"quarter-short":{"0":"this quarter","1":"next quarter","future":{"other":"+{0} Q"},"past":{"other":"-{0} Q"},"-1":"last quarter"},"quarter-narrow":{"0":"this quarter","1":"next quarter","future":{"other":"+{0} Q"},"past":{"other":"-{0} Q"},"-1":"last quarter"},"month":{"0":"this month","1":"next month","future":{"other":"+{0} m"},"past":{"other":"-{0} m"},"-1":"last month"},"month-short":{"0":"this month","1":"next month","future":{"other":"+{0} m"},"past":{"other":"-{0} m"},"-1":"last month"},"month-narrow":{"0":"this month","1":"next month","future":{"other":"+{0} m"},"past":{"other":"-{0} m"},"-1":"last month"},"week":{"0":"this week","1":"next week","future":{"other":"+{0} w"},"past":{"other":"-{0} w"},"-1":"last week"},"week-short":{"0":"this week","1":"next week","future":{"other":"+{0} w"},"past":{"other":"-{0} w"},"-1":"last week"},"week-narrow":{"0":"this week","1":"next week","future":{"other":"+{0} w"},"past":{"other":"-{0} w"},"-1":"last week"},"day":{"0":"today","1":"tomorrow","future":{"other":"+{0} d"},"past":{"other":"-{0} d"},"-1":"yesterday"},"day-short":{"0":"today","1":"tomorrow","future":{"other":"+{0} d"},"past":{"other":"-{0} d"},"-1":"yesterday"},"day-narrow":{"0":"today","1":"tomorrow","future":{"other":"+{0} d"},"past":{"other":"-{0} d"},"-1":"yesterday"},"hour":{"0":"this hour","future":{"other":"+{0} h"},"past":{"other":"-{0} h"}},"hour-short":{"0":"this hour","future":{"other":"+{0} h"},"past":{"other":"-{0} h"}},"hour-narrow":{"0":"this hour","future":{"other":"+{0} h"},"past":{"other":"-{0} h"}},"minute":{"0":"this minute","future":{"other":"+{0} min"},"past":{"other":"-{0} min"}},"minute-short":{"0":"this minute","future":{"other":"+{0} min"},"past":{"other":"-{0} min"}},"minute-narrow":{"0":"this minute","future":{"other":"+{0} min"},"past":{"other":"-{0} min"}},"second":{"0":"now","future":{"other":"+{0} s"},"past":{"other":"-{0} s"}},"second-short":{"0":"now","future":{"other":"+{0} s"},"past":{"other":"-{0} s"}},"second-narrow":{"0":"now","future":{"other":"+{0} s"},"past":{"other":"-{0} s"}}}},"availableLocales":["ps-PK","ps"],"aliases":{},"parentLocales":{}}')}}]);
//# sourceMappingURL=359.8b288954fc14d7f82d4f.index.js.map