(window.webpackJsonp=window.webpackJsonp||[]).push([[341],{536:function(t){t.exports=JSON.parse('{"data":{"mzn":{"nu":["arabext"],"year":{"0":"امسال","1":"سال دیگه","future":{"other":"{0} سال دله"},"past":{"other":"{0} سال پیش"},"-1":"پارسال"},"year-short":{"0":"امسال","1":"سال دیگه","future":{"other":"{0} سال دله"},"past":{"other":"{0} سال پیش"},"-1":"پارسال"},"year-narrow":{"0":"امسال","1":"سال دیگه","future":{"other":"{0} سال دله"},"past":{"other":"{0} سال پیش"},"-1":"پارسال"},"quarter":{"0":"this quarter","1":"next quarter","future":{"other":"{0} ربع دله"},"past":{"other":"{0} ربع پیش"},"-1":"last quarter"},"quarter-short":{"0":"this quarter","1":"next quarter","future":{"other":"{0} ربع دله"},"past":{"other":"{0} ربع پیش"},"-1":"last quarter"},"quarter-narrow":{"0":"this quarter","1":"next quarter","future":{"other":"{0} ربع دله"},"past":{"other":"{0} ربع پیش"},"-1":"last quarter"},"month":{"0":"این ماه","1":"ماه ِبعد","future":{"other":"{0} ماه دله"},"past":{"other":"{0} ماه پیش"},"-1":"ماه قبل"},"month-short":{"0":"این ماه","1":"ماه ِبعد","future":{"other":"{0} ماه دله"},"past":{"other":"{0} ماه پیش"},"-1":"ماه قبل"},"month-narrow":{"0":"این ماه","1":"ماه ِبعد","future":{"other":"{0} ماه دله"},"past":{"other":"{0} ماه پیش"},"-1":"ماه قبل"},"week":{"0":"این هفته","1":"بعدی هفته","future":{"other":"{0} هفته دله"},"past":{"other":"{0} هفته پیش"},"-1":"قبلی هفته"},"week-short":{"0":"این هفته","1":"بعدی هفته","future":{"other":"{0} هفته دله"},"past":{"other":"{0} هفته پیش"},"-1":"قبلی هفته"},"week-narrow":{"0":"این هفته","1":"بعدی هفته","future":{"other":"{0} هفته دله"},"past":{"other":"{0} هفته پیش"},"-1":"قبلی هفته"},"day":{"0":"اَمروز","1":"فِردا","future":{"other":"{0} روز دله"},"past":{"other":"{0} روز پیش"},"-1":"دیروز"},"day-short":{"0":"اَمروز","1":"فِردا","future":{"other":"{0} روز دله"},"past":{"other":"{0} روز پیش"},"-1":"دیروز"},"day-narrow":{"0":"اَمروز","1":"فِردا","future":{"other":"{0} روز دله"},"past":{"other":"{0} روز پیش"},"-1":"دیروز"},"hour":{"0":"this hour","future":{"other":"{0} ساعِت دله"},"past":{"other":"{0} ساعِت پیش"}},"hour-short":{"0":"this hour","future":{"other":"{0} ساعت دله"},"past":{"other":"{0} ساعت پیش"}},"hour-narrow":{"0":"this hour","future":{"other":"{0} ساعت دله"},"past":{"other":"{0} ساعت پیش"}},"minute":{"0":"this minute","future":{"other":"{0} دقیقه دله"},"past":{"other":"{0} دَقه پیش"}},"minute-short":{"0":"this minute","future":{"other":"{0} دَقه دله"},"past":{"other":"{0} دَقه پیش"}},"minute-narrow":{"0":"this minute","future":{"other":"{0} دَقه دله"},"past":{"other":"{0} دَقه پیش"}},"second":{"0":"now","future":{"other":"{0} ثانیه دله"},"past":{"other":"{0} ثانیه پیش"}},"second-short":{"0":"now","future":{"other":"{0} ثانیه دله"},"past":{"other":"{0} ثانیه پیش"}},"second-narrow":{"0":"now","future":{"other":"{0} ثانیه دله"},"past":{"other":"{0} ثانیه پیش"}}}},"availableLocales":["mzn"],"aliases":{},"parentLocales":{}}')}}]);
//# sourceMappingURL=341.8b288954fc14d7f82d4f.index.js.map