(window.webpackJsonp=window.webpackJsonp||[]).push([[291],{486:function(t){t.exports=JSON.parse('{"data":{"jv":{"nu":["latn"],"year":{"0":"taun iki","1":"taun ngarep","future":{"other":"ing {0} taun"},"past":{"other":"{0} taun kepungkur"},"-1":"taun wingi"},"year-short":{"0":"taun iki","1":"taun ngarep","future":{"other":"ing {0} tn"},"past":{"other":"{0} tn kepungkur"},"-1":"taun wingi"},"year-narrow":{"0":"taun iki","1":"taun ngarep","future":{"other":"+{0} y"},"past":{"other":"-{0} y"},"-1":"taun wingi"},"quarter":{"0":"kwartal iki","1":"kwartal ngarep","future":{"other":"ing {0} kwartal"},"past":{"other":"{0} kwartal kepungkur"},"-1":"kwartal wingi"},"quarter-short":{"0":"kwartal iki","1":"kwartal ngarep","future":{"other":"ing {0} kwrt."},"past":{"other":"{0} kwrt. kepungkur"},"-1":"kwartal wingi"},"quarter-narrow":{"0":"kwartal iki","1":"kwartal ngarep","future":{"other":"+{0} Q"},"past":{"other":"-{0} Q"},"-1":"kwartal wingi"},"month":{"0":"sasi iki","1":"sasi ngarep","future":{"other":"ing {0} sasi"},"past":{"other":"{0} sasi kepungkur"},"-1":"sasi wingi"},"month-short":{"0":"sasi iki","1":"sasi ngarep","future":{"other":"ing {0} s."},"past":{"other":"{0} s. kepungkur"},"-1":"sasi wingi"},"month-narrow":{"0":"sasi iki","1":"sasi ngarep","future":{"other":"+{0} m"},"past":{"other":"-{0} m"},"-1":"sasi wingi"},"week":{"0":"pekan iki","1":"pekan ngarep","future":{"other":"ing {0} minggu"},"past":{"other":"{0} minggu kepungkur"},"-1":"pekan wingi"},"week-short":{"0":"pekan iki","1":"pekan ngarep","future":{"other":"ing {0} mgg."},"past":{"other":"{0} mgg. kepungkur"},"-1":"pekan wingi"},"week-narrow":{"0":"pekan iki","1":"pekan ngarep","future":{"other":"+{0} w"},"past":{"other":"-{0} w"},"-1":"pekan wingi"},"day":{"0":"saiki","1":"sesuk","future":{"other":"ing {0} dina"},"past":{"other":"{0} dina kepungkur"},"-1":"wingi"},"day-short":{"0":"saiki","1":"sesuk","future":{"other":"ing {0} dina"},"past":{"other":"-{0} d"},"-1":"wingi"},"day-narrow":{"0":"saiki","1":"sesuk","future":{"other":"+{0} d"},"past":{"other":"-{0} d"},"-1":"wingi"},"hour":{"0":"jam iki","future":{"other":"ing {0} jam"},"past":{"other":"{0} jam kepungkur"}},"hour-short":{"0":"jam iki","future":{"other":"+{0} h"},"past":{"other":"-{0} h"}},"hour-narrow":{"0":"jam iki","future":{"other":"+{0} h"},"past":{"other":"-{0} h"}},"minute":{"0":"menit iki","future":{"other":"ing {0} mnt"},"past":{"other":"{0} men. kepungkur"}},"minute-short":{"0":"menit iki","future":{"other":"+{0} min"},"past":{"other":"-{0} min"}},"minute-narrow":{"0":"menit iki","future":{"other":"+{0} min"},"past":{"other":"-{0} min"}},"second":{"0":"now","future":{"other":"ing {0} detik"},"past":{"other":"{0} detik kepungkur"}},"second-short":{"0":"now","future":{"other":"ing {0} dtk"},"past":{"other":"{0} det. kepungkur"}},"second-narrow":{"0":"now","future":{"other":"+{0} s"},"past":{"other":"-{0} s"}}}},"availableLocales":["jv"],"aliases":{},"parentLocales":{}}')}}]);
//# sourceMappingURL=291.8b288954fc14d7f82d4f.index.js.map